from setuptools import setup

setup(name='udacityMLE_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['udacityMLE_distributions'],
      zip_safe=False)
